# -*- coding: UTF-8 -*-

from artix.common.py2to3utils import configparser
import logging
import logging.config


class SimpleLogger(object):
    """ Логгер """
    # словарь с макроподстановками для логгеров, сделано, потому что логгеры перезатирались при каждой инициализации SimpleLogger
    defaults = {}
    configs = []

    def __init__(self, filename, name='root', configPath='', dictConfigObject={'version': 1}):
        if not SimpleLogger.defaults or configPath not in self.configs:
            self.__initDefaults(filename, configPath)
        else:
            SimpleLogger.defaults[name] = filename
        try:
            logging.config.fileConfig(configPath, defaults=SimpleLogger.defaults, disable_existing_loggers=False)
        except Exception:
            logging.config.dictConfig(dictConfigObject)
        self.logger = logging.getLogger(name)

    def getLogger(self):
        return self.logger

    def __initDefaults(self, filename, configPath):
        """ Считываем конфиг логгера и заполняем словарь. Изначально для всех логов будет один путь, чтобы не создавались пустые файлы"""
        cp = configparser.ConfigParser()
        if cp.read(configPath):
            loggers = cp.get('loggers', 'keys')
            if len(loggers):
                loggers_list = loggers.split(",")
                for logger in loggers_list:
                    if logger.strip() not in SimpleLogger.defaults:
                        SimpleLogger.defaults[logger.strip()] = filename
            if configPath not in self.configs:
                self.configs.append(configPath)
